@@ -15,8 +15,12 @@ package Sidef::Types::Hash::Hash {
     use Sidef::Types::Block::Block;
 
     sub new {
-        my (undef, %pairs) = @_;
-        bless \%pairs;
+        (@_ == 2 && ref($_[1]) eq 'HASH')
+          ? bless($_[1])
+          : do {
+            shift(@_);
+            bless {@_};
+          };
     }
 
     *call = \&new;
@@ -47,6 +51,7 @@ package Sidef::Types::Hash::Hash {
             $addr{$refaddr};
         };
 
+        no warnings 'redefine';
         local *Sidef::Types::Hash::Hash::get_value = $sub;
         $sub->($_[0]);
     }
@@ -144,6 +149,8 @@ package Sidef::Types::Hash::Hash {
         };
 
         no strict 'refs';
+        no warnings 'redefine';
+
         local *{__PACKAGE__ . '::' . 'eq'} = $sub;
         local *{__PACKAGE__ . '::' . '=='} = $sub;
         $sub->($self, $hash);
@@ -512,6 +519,7 @@ package Sidef::Types::Hash::Hash {
             $addr{$refaddr};
         };
 
+        no warnings 'redefine';
         local *Sidef::Types::Hash::Hash::as_tree = $sub;
         $sub->($_[0], $root);
     }
@@ -690,6 +698,7 @@ package Sidef::Types::Hash::Hash {
             $str;
         };
 
+        no warnings 'redefine';
         local *Sidef::Types::Hash::Hash::dump = $sub;
         $sub->($_[0]);
     }
