@@ -34,8 +34,7 @@ my %ignored_methods = (
                        'Sidef'                          => [qw(new)],
                        'Sidef::Sys::Sys'                => [qw(new)],
                        'Sidef::Math::Math'              => [qw(new)],
-                       'Sidef::Time::Localtime'         => [qw(new)],
-                       'Sidef::Time::Gmtime'            => [qw(new)],
+                       'Sidef::Time::Date'              => [qw(new)],
                        'Sidef::Types::Glob::DirHandle'  => [qw(new)],
                        'Sidef::Types::Glob::FileHandle' => [qw(new)],
                        'Sidef::Types::Glob::Backtick'   => [qw(new)],
